Class: Aws::CloudHSMV2::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudHSMV2::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudhsmv2/client.rb,
sig/client.rbs
Overview
An API client for CloudHSMV2. To construct a client, you need to configure a :region and :credentials.
client = Aws::CloudHSMV2::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CopyBackupToRegionResponseSuccess, _CreateClusterResponseSuccess, _CreateHsmResponseSuccess, _DeleteBackupResponseSuccess, _DeleteClusterResponseSuccess, _DeleteHsmResponseSuccess, _DeleteResourcePolicyResponseSuccess, _DescribeBackupsResponseSuccess, _DescribeClustersResponseSuccess, _GetResourcePolicyResponseSuccess, _InitializeClusterResponseSuccess, _ListTagsResponseSuccess, _ModifyBackupAttributesResponseSuccess, _ModifyClusterResponseSuccess, _PutResourcePolicyResponseSuccess, _RestoreBackupResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#copy_backup_to_region(params = {}) ⇒ Types::CopyBackupToRegionResponse
Copy an CloudHSM cluster backup to a different region.
-
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a new CloudHSM cluster.
-
#create_hsm(params = {}) ⇒ Types::CreateHsmResponse
Creates a new hardware security module (HSM) in the specified CloudHSM cluster.
-
#delete_backup(params = {}) ⇒ Types::DeleteBackupResponse
Deletes a specified CloudHSM backup.
-
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes the specified CloudHSM cluster.
-
#delete_hsm(params = {}) ⇒ Types::DeleteHsmResponse
Deletes the specified HSM.
-
#delete_resource_policy(params = {}) ⇒ Types::DeleteResourcePolicyResponse
Deletes an CloudHSM resource policy.
-
#describe_backups(params = {}) ⇒ Types::DescribeBackupsResponse
Gets information about backups of CloudHSM clusters.
-
#describe_clusters(params = {}) ⇒ Types::DescribeClustersResponse
Gets information about CloudHSM clusters.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Retrieves the resource policy document attached to a given resource.
-
#initialize_cluster(params = {}) ⇒ Types::InitializeClusterResponse
Claims an CloudHSM cluster by submitting the cluster certificate issued by your issuing certificate authority (CA) and the CA's root certificate.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Gets a list of tags for the specified CloudHSM cluster.
-
#modify_backup_attributes(params = {}) ⇒ Types::ModifyBackupAttributesResponse
Modifies attributes for CloudHSM backup.
-
#modify_cluster(params = {}) ⇒ Types::ModifyClusterResponse
Modifies CloudHSM cluster.
-
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Creates or updates an CloudHSM resource policy.
-
#restore_backup(params = {}) ⇒ Types::RestoreBackupResponse
Restores a specified CloudHSM backup that is in the
PENDING_DELETIONstate. -
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites one or more tags for the specified CloudHSM cluster.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tag or tags from the specified CloudHSM cluster.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-cloudhsmv2/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1612 1613 1614 |
# File 'lib/aws-sdk-cloudhsmv2/client.rb', line 1612 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1615 1616 1617 |
# File 'lib/aws-sdk-cloudhsmv2/client.rb', line 1615 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 |
# File 'lib/aws-sdk-cloudhsmv2/client.rb', line 1585 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CloudHSMV2') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloudhsmv2' context[:gem_version] = '1.94.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_backup_to_region(params = {}) ⇒ Types::CopyBackupToRegionResponse
Copy an CloudHSM cluster backup to a different region.
Cross-account use: No. You cannot perform this operation on an CloudHSM backup in a different Amazon Web Services account.
87 |
# File 'sig/client.rbs', line 87
def copy_backup_to_region: (
|
#create_cluster(params = {}) ⇒ Types::CreateClusterResponse
Creates a new CloudHSM cluster.
Cross-account use: Yes. To perform this operation with an CloudHSM backup in a different AWS account, specify the full backup ARN in the value of the SourceBackupId parameter.
104 |
# File 'sig/client.rbs', line 104
def create_cluster: (
|
#create_hsm(params = {}) ⇒ Types::CreateHsmResponse
Creates a new hardware security module (HSM) in the specified CloudHSM cluster.
Cross-account use: No. You cannot perform this operation on an CloudHSM cluster in a different Amazon Web Service account.
128 |
# File 'sig/client.rbs', line 128
def create_hsm: (
|
#delete_backup(params = {}) ⇒ Types::DeleteBackupResponse
Deletes a specified CloudHSM backup. A backup can be restored up to 7 days after the DeleteBackup request is made. For more information on restoring a backup, see RestoreBackup.
Cross-account use: No. You cannot perform this operation on an CloudHSM backup in a different Amazon Web Services account.
140 |
# File 'sig/client.rbs', line 140
def delete_backup: (
|
#delete_cluster(params = {}) ⇒ Types::DeleteClusterResponse
Deletes the specified CloudHSM cluster. Before you can delete a cluster, you must delete all HSMs in the cluster. To see if the cluster contains any HSMs, use DescribeClusters. To delete an HSM, use DeleteHsm.
Cross-account use: No. You cannot perform this operation on an CloudHSM cluster in a different Amazon Web Services account.
150 |
# File 'sig/client.rbs', line 150
def delete_cluster: (
|
#delete_hsm(params = {}) ⇒ Types::DeleteHsmResponse
Deletes the specified HSM. To specify an HSM, you can use its identifier (ID), the IP address of the HSM's elastic network interface (ENI), or the ID of the HSM's ENI. You need to specify only one of these values. To find these values, use DescribeClusters.
Cross-account use: No. You cannot perform this operation on an CloudHSM hsm in a different Amazon Web Services account.
160 |
# File 'sig/client.rbs', line 160
def delete_hsm: (
|
#delete_resource_policy(params = {}) ⇒ Types::DeleteResourcePolicyResponse
Deletes an CloudHSM resource policy. Deleting a resource policy will result in the resource being unshared and removed from any RAM resource shares. Deleting the resource policy attached to a backup will not impact any clusters created from that backup.
Cross-account use: No. You cannot perform this operation on an CloudHSM resource in a different Amazon Web Services account.
174 |
# File 'sig/client.rbs', line 174
def delete_resource_policy: (
|
#describe_backups(params = {}) ⇒ Types::DescribeBackupsResponse
Gets information about backups of CloudHSM clusters. Lists either the backups you own or the backups shared with you when the Shared parameter is true.
This is a paginated operation, which means that each response might
contain only a subset of all the backups. When the response contains
only a subset of backups, it includes a NextToken value. Use this
value in a subsequent DescribeBackups request to get more backups.
When you receive a response with no NextToken (or an empty or null
value), that means there are no more backups to get.
Cross-account use: Yes. Customers can describe backups in other Amazon Web Services accounts that are shared with them.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
185 |
# File 'sig/client.rbs', line 185
def describe_backups: (
|
#describe_clusters(params = {}) ⇒ Types::DescribeClustersResponse
Gets information about CloudHSM clusters.
This is a paginated operation, which means that each response might
contain only a subset of all the clusters. When the response contains
only a subset of clusters, it includes a NextToken value. Use this
value in a subsequent DescribeClusters request to get more clusters.
When you receive a response with no NextToken (or an empty or null
value), that means there are no more clusters to get.
Cross-account use: No. You cannot perform this operation on CloudHSM clusters in a different Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
200 |
# File 'sig/client.rbs', line 200
def describe_clusters: (
|
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Retrieves the resource policy document attached to a given resource.
Cross-account use: No. You cannot perform this operation on an CloudHSM resource in a different Amazon Web Services account.
212 |
# File 'sig/client.rbs', line 212
def get_resource_policy: (
|
#initialize_cluster(params = {}) ⇒ Types::InitializeClusterResponse
Claims an CloudHSM cluster by submitting the cluster certificate issued by your issuing certificate authority (CA) and the CA's root certificate. Before you can claim a cluster, you must sign the cluster's certificate signing request (CSR) with your issuing CA. To get the cluster's CSR, use DescribeClusters.
Cross-account use: No. You cannot perform this operation on an CloudHSM cluster in a different Amazon Web Services account.
223 |
# File 'sig/client.rbs', line 223
def initialize_cluster: (
|
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Gets a list of tags for the specified CloudHSM cluster.
This is a paginated operation, which means that each response might
contain only a subset of all the tags. When the response contains only
a subset of tags, it includes a NextToken value. Use this value in a
subsequent ListTags request to get more tags. When you receive a
response with no NextToken (or an empty or null value), that means
there are no more tags to get.
Cross-account use: No. You cannot perform this operation on an CloudHSM resource in a different Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
236 |
# File 'sig/client.rbs', line 236
def list_tags: (
|
#modify_backup_attributes(params = {}) ⇒ Types::ModifyBackupAttributesResponse
Modifies attributes for CloudHSM backup.
Cross-account use: No. You cannot perform this operation on an CloudHSM backup in a different Amazon Web Services account.
248 |
# File 'sig/client.rbs', line 248
def modify_backup_attributes: (
|
#modify_cluster(params = {}) ⇒ Types::ModifyClusterResponse
Modifies CloudHSM cluster.
Cross-account use: No. You cannot perform this operation on an CloudHSM cluster in a different Amazon Web Services account.
259 |
# File 'sig/client.rbs', line 259
def modify_cluster: (
|
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Creates or updates an CloudHSM resource policy. A resource policy helps you to define the IAM entity (for example, an Amazon Web Services account) that can manage your CloudHSM resources. The following resources support CloudHSM resource policies:
- Backup - The resource policy allows you to describe the backup and restore a cluster from the backup in another Amazon Web Services account.
^
In order to share a backup, it must be in a 'READY' state and you must own it.
While you can share a backup using the CloudHSM PutResourcePolicy operation, we recommend using Resource Access Manager (RAM) instead. Using RAM provides multiple benefits as it creates the policy for you, allows multiple resources to be shared at one time, and increases the discoverability of shared resources. If you use PutResourcePolicy and want consumers to be able to describe the backups you share with them, you must promote the backup to a standard RAM Resource Share using the RAM PromoteResourceShareCreatedFromPolicy API operation. For more information, see Working with shared backups in the CloudHSM User Guide
Cross-account use: No. You cannot perform this operation on an CloudHSM resource in a different Amazon Web Services account.
275 |
# File 'sig/client.rbs', line 275
def put_resource_policy: (
|
#restore_backup(params = {}) ⇒ Types::RestoreBackupResponse
Restores a specified CloudHSM backup that is in the PENDING_DELETION
state. For more information on deleting a backup, see DeleteBackup.
Cross-account use: No. You cannot perform this operation on an CloudHSM backup in a different Amazon Web Services account.
286 |
# File 'sig/client.rbs', line 286
def restore_backup: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or overwrites one or more tags for the specified CloudHSM cluster.
Cross-account use: No. You cannot perform this operation on an CloudHSM resource in a different Amazon Web Services account.
295 |
# File 'sig/client.rbs', line 295
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tag or tags from the specified CloudHSM cluster.
Cross-account use: No. You cannot perform this operation on an CloudHSM resource in a different Amazon Web Services account.
310 |
# File 'sig/client.rbs', line 310
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1605 1606 1607 |
# File 'lib/aws-sdk-cloudhsmv2/client.rb', line 1605 def waiter_names [] end |